@@ -9,5 +9,5 @@ from __future__ import annotations
 from .cli import main
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     main()
